﻿/*
   Copyright 2015 Bennett Adelson Consulting

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
 */

using System;
using Azure.Tests.Properties;
using FluentAssertions;
using Newtonsoft.Json;
using PhotoGallery.Common;
using Xunit;

namespace Azure.Tests
{
    public class QueueTests
    {
        private const string QueueName = "send-email";

        [Fact(Skip = "Broken test runner")]
        public void CanConnectToQueue()
        {
            string connectionString = Settings.Default.StorageConnectionString;
            using (var queueAccessor = new QueueAccessor(connectionString))
            {
                queueAccessor.Connect();

                Console.WriteLine("Successfully connected.");
            }
            Console.WriteLine("Successfully disconnected");
        }

        [Fact(Skip = "Broken test runner")]
        //[Fact]
        public void CanPeekAtQueue()
        {
            string connectionString = Settings.Default.StorageConnectionString;
            using (var queueAccessor = new QueueAccessor(connectionString))
            {
                queueAccessor.Connect();
                Console.WriteLine("Successfully connected.");

                var peekedMessage = queueAccessor.PeekAtQueue(QueueName);
                Console.WriteLine("Peeked message: {0}", JsonUtility.ToJsonPretty(peekedMessage));
            }
            Console.WriteLine("Successfully disconnected");
        }

        [Fact(Skip = "Broken test runner")]
        public void Dequeue()
        {
            string connectionString = Settings.Default.StorageConnectionString;
            using (var queueAccessor = new QueueAccessor(connectionString))
            {
                queueAccessor.Connect();
                Console.WriteLine("Successfully connected.");

                var peekedMessage = queueAccessor.GetMessage(QueueName);
                Console.WriteLine("Peeked message: {0}", JsonUtility.ToJsonPretty(peekedMessage));
            }
            Console.WriteLine("Successfully disconnected");
        }

        [Fact(Skip = "Broken test runner")]
        public void CanQueueAndPeekAtMessage()
        {
            string connectionString = Settings.Default.StorageConnectionString;
            using (var queueAccessor = new QueueAccessor(connectionString))
            {
                queueAccessor.Connect();
                Console.WriteLine("Successfully connected.");

                string json = JsonUtility.ToJson(new {FirstName = "Jim", LastName = "Smith"});
                queueAccessor.InsertIntoQueue(QueueName, json);
                Console.WriteLine("Queued: {0}", json);
            }
            Console.WriteLine("Successfully disconnected");

            using (var queueAccessor = new QueueAccessor(connectionString))
            {
                queueAccessor.Connect();
                Console.WriteLine("Successfully connected.");

                var peekedMessage = queueAccessor.PeekAtQueue(QueueName);
                Console.WriteLine("Peeked message: {0}", JsonUtility.ToJsonPretty(peekedMessage));
            }
            Console.WriteLine("Successfully disconnected");
        }

        //[Fact(Skip = "Broken test runner")]
        [Fact]
        public void CanQueueAndDequeueMessage()
        {
            string connectionString = Settings.Default.StorageConnectionString;
            Guid messageId = Guid.NewGuid();
            using (var queueAccessor = new QueueAccessor(connectionString))
            {
                queueAccessor.Connect();
                Console.WriteLine("Successfully connected.");

                string json =
                    JsonUtility.ToJson(new TestMessageClass {FirstName = "Jim", LastName = "Smith", Id = messageId});
                queueAccessor.InsertIntoQueue(QueueName, json);
                Console.WriteLine("Queued: {0}", json);
            }
            Console.WriteLine("Successfully disconnected");

            using (var queueAccessor = new QueueAccessor(connectionString))
            {
                queueAccessor.Connect();
                Console.WriteLine("Successfully connected.");

                var peekedMessage = queueAccessor.GetMessage(QueueName);
                Console.WriteLine("Fetched message: {0}", JsonUtility.ToJsonPretty(peekedMessage));

                TestMessageClass message = JsonConvert.DeserializeObject<TestMessageClass>(peekedMessage.AsString);
                message.Id.Should().Be(messageId, "Should have dequeued our message.");
            }
            Console.WriteLine("Successfully disconnected");
        }

        private class TestMessageClass
        {
            public Guid Id { get; set; }
            public string FirstName { get; set; }
            public string LastName { get; set; }
        }
    }
}
