﻿/*
Copyright 2015 Bennett Adelson Consulting

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

using System.IO;
using System.Net;
using System.Net.Mail;

namespace PhotoGallery.Common
{
    public class EmailSender
    {
        private const int TLS_PORT = 587;
        private const int SSL_PORT = 465;
        private const string SmtpHost = "smtp.gmail.com";

        public EmailSender()
        {
        }

        public EmailSender(string connectionString) : this()
        {
            ConnectionString = connectionString;
        }

        public string ConnectionString { get; private set; }

        public void SendPhoto(SendPhotoParams sendPhotoParams)
        {
            const string body = "Attached is a photograph I thought you would find interesting.";
            var mailMessage = new MailMessage(sendPhotoParams.FromAddress, sendPhotoParams.ToAddress,
                sendPhotoParams.Subject, body);

            byte[] imageObject = sendPhotoParams.ImageObject;
            if (imageObject != null)
            {
                var memoryStream = new MemoryStream(imageObject);
                Attachment photoAttachment = new Attachment(memoryStream, "Photo.jpg");
                mailMessage.Attachments.Add(photoAttachment);
            }

            using (var smtpServer = new SmtpClient(SmtpHost, TLS_PORT))
            {
                smtpServer.Credentials = new NetworkCredential(StmpUsername, SmtpPassword);
                smtpServer.EnableSsl = true;
                smtpServer.Send(mailMessage);
            }
        }

        public void SendPhoto(int photoId, string subject, string toAddress, string fromAddress)
        {
            var sendPhotoParams = new SendPhotoParams(photoId, subject, toAddress, fromAddress);
            SendPhoto(sendPhotoParams);
        }

        #region Credentials

        private const string StmpUsername = "jjrazuredemo@gmail.com";
        private const string SmtpPassword = "Op-yDtS_?d9O";

        #endregion
    }
}
