﻿/*
Copyright 2015 Bennett Adelson Consulting

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

using System;
using Microsoft.WindowsAzure.Storage;
using Microsoft.WindowsAzure.Storage.Queue;

namespace PhotoGallery.Common
{
    public class QueueAccessor : IDisposable
    {
        private CloudStorageAccount _storageAccount;
        public string ConnectionString { get; set; }

        public QueueAccessor(string connectionString)
        {
            ConnectionString = connectionString;
        }

        public void Dispose()
        {
            Disconnect();
        }

        public void Connect()
        {
            if (_storageAccount == null)
            {
                _storageAccount = CloudStorageAccount.Parse(ConnectionString);
            }
        }

        private void Disconnect()
        {
            // ReSharper disable once RedundantCheckBeforeAssignment
            if (_storageAccount != null)
            {
                _storageAccount = null;
            }
        }

        public CloudQueueMessage PeekAtQueue(string queueName)
        {
            var queueClient = _storageAccount.CreateCloudQueueClient();
            var queue = queueClient.GetQueueReference(queueName);
            var peekedMessage = queue.PeekMessage();
            return peekedMessage;
        }

        public CloudQueueMessage InsertIntoQueue(string queueName, string content)
        {
            Connect();

            var queueClient = _storageAccount.CreateCloudQueueClient();
            var queue = queueClient.GetQueueReference(queueName);
            queue.CreateIfNotExists();
            var message = new CloudQueueMessage(content);
            queue.AddMessage(message);
            return message;
        }

        public CloudQueueMessage GetMessage(string queueName)
        {
            var queueClient = _storageAccount.CreateCloudQueueClient();
            var queue = queueClient.GetQueueReference(queueName);
            var message = queue.GetMessage();
            if (message != null)
            {
                queue.DeleteMessage(message);
            }
            return message;
        }
    }
}
