﻿/*
Copyright 2015 Bennett Adelson Consulting

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

using System;
using System.Drawing.Imaging;
using System.IO;
using Microsoft.Azure.WebJobs;
using Newtonsoft.Json;
using Newtonsoft.Json.Linq;
using PhotoGallery.Common;

namespace SendEmail
{

    public class Functions
    {
        public static void SendEmail([QueueTrigger("send-email")] string sendEmailJson, TextWriter log)
        {
            log.WriteLine("Received message from send-email");
            var emailSender = new EmailSender();
            try
            {
                log.WriteLine("Sending email ...");
                var jsonObject = JObject.Parse(sendEmailJson);
                int photoId = Convert.ToInt32(jsonObject.SelectToken("PhotoId"));
                string subject = jsonObject.SelectToken("Subject").ToString();
                string toAddress = jsonObject.SelectToken("ToAddress").ToString();
                string fromAddress = jsonObject.SelectToken("FromAddress").ToString();
                var imageObject = Properties.Resources.thumbnail;
                var memoryStream = new MemoryStream();
                imageObject.Save(memoryStream, ImageFormat.Jpeg);
                SendPhotoParams sendEmailMessage = new SendPhotoParams(photoId, subject, toAddress, fromAddress)
                {
                    ImageObject = memoryStream.ToArray()
                };
                emailSender.SendPhoto(sendEmailMessage);
                log.WriteLine("Email successfully sent.");
            }
            catch (Exception ex)
            {
                log.WriteLine(ex.Message);
            }
        }
    }
}
